@@ -7,10 +7,7 @@ Usage::
     import boto3
     from mypy_boto3_cloudhsm import CloudHSMClient
 
-    session = boto3.Session()
-
     client: CloudHSMClient = boto3.client("cloudhsm")
-    session_client: CloudHSMClient = session.client("cloudhsm")
     ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
