@@ -7,7 +7,7 @@ Usage::
     import boto3
 
     from mypy_boto3_cloudhsm import CloudHSMClient
-    from mypy_boto3_cloudhsm import (
+    from mypy_boto3_cloudhsm.paginator import (
         ListHapgsPaginator,
         ListHsmsPaginator,
         ListLunaClientsPaginator,
